@@ -52,13 +52,14 @@ def logline(*args):
     msg = '%s %s' % (cstr(caller, 'yellow'), args[0])
     logging.warning(msg, *args[1:])
 
-def shell(cmd, cwd=None, env=None):
+def shell(cmd, cwd=None, env=None, decode_utf8=True):
     if type(cmd) not in (tuple, list):
         cmd = shlex.split(cmd)
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False, cwd=cwd, env=env)
     stdout, stderr = proc.communicate()
-    stdout = stdout.decode('utf-8').strip()
-    stderr = stderr.decode('utf-8').strip()
+    if decode_utf8:
+        stdout = stdout.decode('utf-8').strip()
+        stderr = stderr.decode('utf-8').strip()
     return (stdout, stderr, proc.returncode)
 
 def multi_shell(cmds, cwd=None, env=None):
@@ -122,6 +123,21 @@ def split_name(name):
 def map_items(items, key):
     return dict([(item[key], item) for item in items])
 
+# From Maxime Biais's comment on http://www.peterbe.com/plog/uniqifiers-benchmark
+# Preserves order of the iterable in the return value
+def unique_list(iterable):
+    m = set()
+    return list(filter(lambda x: not (m.__contains__(x) or m.add(x)), iterable))
+
+# From the accepted answer on http://stackoverflow.com/questions/642763/python-intersection-of-two-lists
+# Preserves order of the items in the second iterable
+def stable_intersection(iter1, iter2):
+    return list(itertools.ifilter(set(iter1).__contains__, iter2))
+
+# Modified from above - remove items in 'iter_remove' from items in 'iter_keep'
+def stable_difference(iter_remove, iter_keep):
+    return list(itertools.ifilterfalse(set(iter_remove).__contains__, iter_keep))
+
 
 class DateTimeEncoder(json.JSONEncoder):
     def default(self, obj):
