@@ -285,7 +285,7 @@ class AegisHandler(tornado.web.RequestHandler):
             return name
         # Authentication for special -admin environment to use cookies from the main env
         if self.tmpl['env'].endswith('-admin'):
-            name = "%s_%s" % (self.tmpl['env'].split('-')[0], name)
+            name = "%s_%s" % (self.tmpl['env'].rsplit('-', maxsplit=1)[0], name)
         else:
             name = "%s_%s" % (self.tmpl['env'], name)
         return name
